@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """
 git-recipe is a small recipe that allows you to use git
-repositories 
+repositories
 
 [buildout]
 parts = data
@@ -14,18 +14,28 @@ as_egg = true
 
 """
 
-import logging, os, zc.buildout, subprocess, re, shutil
+import os
 
+from zc.buildout import easy_install
+from zc.buildout import UserError
+
+from subprocess import Popen
+from subprocess import PIPE
+from shutil import rmtree
+
+from re import search
+from re import findall
+from re import MULTILINE
 
 def get_reponame(url):
     if ":" in url:
         url = '/' + url.rsplit(":", 1)[1]
-    match = re.search('\/(?P<repo_name>[a-zA-Z0-9-_.]*)(.git)$', url)
+    match = search('\/(?P<repo_name>[a-zA-Z0-9-_.]*)(.git)$', url)
     if match:
         repo_name = match.groupdict()['repo_name']
         return repo_name
     else:
-        raise zc.buildout.UserError('Can not find repository name')
+        raise UserError('Can not find repository name')
 
 
 class GitRecipe(object):
@@ -34,27 +44,20 @@ class GitRecipe(object):
         self.options, self.buildout = options, buildout
 
         if 'repository' not in self.options:
-            raise zc.buildout.UserError('Repository url must be provided')
+            raise UserError('Repository url must be provided')
         self.url = options['repository']
-        # ref option overrides rev
-        if 'rev' in options:
-            self.ref = options.get('rev', 'origin/master')
-        if 'ref' in options:
-            self.ref = options.get('ref', 'origin/master')
+        self.ref = options.get('ref', 'origin/master')
 
         self.as_egg = options.get('as_egg', 'false').lower() == 'true'
         self.options['download-directory'] = options.get('download-directory') or buildout['buildout']['parts-directory']
 
         # determine repository name
-        repo_name = get_reponame(self.url)
-        self.repo_path = os.path.join(self.options['download-directory'], repo_name)
+        self.repo_name = options.get('repo_name', get_reponame(self.url))
+        self.repo_path = os.path.join(self.options['download-directory'], self.repo_name)
         self.options['location'] = os.path.join(self.options['download-directory'], self.repo_path)
 
         self.paths = options.get('paths', None)
-        if buildout['buildout'].get('offline').lower() == 'true':
-            self.update = lambda: ()
-        if self.options.get('newest', 'true').lower() == 'false':
-            self.update = lambda: ()
+        self.rename
 
     def git(self, operation, args, quiet=True):
         if quiet:
@@ -62,10 +65,10 @@ class GitRecipe(object):
         else:
             command = ['git'] + [operation] + args
 
-        proc = subprocess.Popen(' '.join(command), shell=True, stdout=subprocess.PIPE)
+        proc = Popen(' '.join(command), shell=True, stdout=PIPE)
         status = proc.wait()
         if status:
-            raise zc.buildout.UserError('Error while executing %s' % ' '.join(command))
+            raise UserError('Error while executing %s' % ' '.join(command))
         return proc.stdout.read()
 
     def check_same(self):
@@ -75,7 +78,7 @@ class GitRecipe(object):
         if os.path.exists(self.repo_path) and os.path.exists(os.path.join(self.repo_path, '.git')):
             os.chdir(self.repo_path)
             origin = self.git('remote', ['show', 'origin'], quiet=False)
-            existing_repository = re.findall('^\s*Fetch URL:\s*(.*)$', origin, flags=re.MULTILINE)[0]
+            existing_repository = findall('^\s*Fetch URL:\s*(.*)$', origin, flags=MULTILINE)[0]
 
         os.chdir(old_cwd)
         if existing_repository == self.url:
@@ -96,31 +99,29 @@ class GitRecipe(object):
                     _installed = True
                     os.chdir(self.repo_path)
                     self.git('fetch', [self.url, ])
-                    if 'rev' in self.options:
-                        os.chdir(self.options['location'])
-                        self.git('checkout', [self.ref, ])
-                        # return to root directory
-                        os.chdir(self.buildout['buildout']['directory'])
-                        #return self.options['location']
+
+                    os.chdir(self.options['location'])
+                    self.git('checkout', [self.ref, ])
+                    # return to root directory
+                    os.chdir(self.buildout['buildout']['directory'])
 
                 else:
                     # if repository exists but not the same, delete all files there
-                    shutil.rmtree(self.repo_path, ignore_errors=True)
+                    rmtree(self.repo_path, ignore_errors=True)
                     _installed = False
 
             # in fact, the install
             if not _installed:
                 os.chdir(self.options['download-directory'])
-                self.git('clone', [self.url, ])
-                # if revision is given, checkout to revision 
-                if 'rev' in self.options:
-                    os.chdir(self.options['location'])
-                    self.git('checkout', [self.ref, ])
+                self.git('clone', [self.url, self.repo_name])
+
+                os.chdir(self.options['location'])
+                self.git('checkout', [self.ref, ])
 
 
-        except zc.buildout.UserError:
+        except UserError:
             # should manually clean files because buildout thinks that no files created
-            shutil.rmtree(self.options['location'])
+            rmtree(self.options['location'])
             raise
 
 
@@ -132,13 +133,17 @@ class GitRecipe(object):
 
     def update(self):
         '''Update repository rather than download it again'''
+
+        if buildout['buildout'].get('offline').lower() == 'true' or \
+           self.options.get('newest', 'true').lower() == 'false':
+            return
+
         # go to parts directory
         if self.check_same():
             os.chdir(self.options['location'])
             self.git('fetch', ['origin', ])
             # if revision is given, checkout to revision
-            if 'rev' in self.options:
-                self.git('checkout', [self.ref, ])
+            self.git('checkout', [self.ref, ])
             if self.as_egg:
                 self._install_as_egg()
         else:
@@ -153,7 +158,7 @@ class GitRecipe(object):
         Install clone as development egg.
         """
         def _install(path, target):
-            zc.buildout.easy_install.develop(path, target)
+            easy_install.develop(path, target)
 
         target = self.buildout['buildout']['develop-eggs-directory']
         if self.paths:
